
# My Notebook App

My Notebook App is a simple notebook application where you can take and organize your notes.

## Features

- Create new notes
- Edit existing notes
- Organize notes into categories
- Search for notes
- User-friendly interface

## Installation

Clone the repository:

```
git clone https://github.com/hw010101/my_notebook_app.git
```
You can install My Notebook App using the following command:

```bash
cd my_notebook_app  
pip install my-notebook-app
```


To start My Notebook App, run the following command:

```
python3 my_notebook_app.py   

